;; Generated package description from elisa.el  -*- no-byte-compile: t -*-
(define-package "elisa" "1.0.3.0.20240719.60641" "Emacs Lisp Information System Assistant" '((emacs "29.2") (ellama "0.11.2") (llm "0.9.1") (async "1.9.8") (plz "0.9")) :commit "7298d3ee8da09005520722a6e160cb0ef66f16e9" :authors '(("Sergey Kostyaev" . "sskostyaev@gmail.com")) :maintainer '("Sergey Kostyaev" . "sskostyaev@gmail.com") :keywords '("help" "local" "tools") :url "http://github.com/s-kostyaev/elisa")
